Learn R Programming

phonR (version 1.0-1)

Vowel space area functions: Calculate the area of a vowel space

Description

Calculate the area of an F2 x F1 vowel space, either as the area of a polygon connecting vowel formant means, or the area of a convex hull encompassing all tokens.

Usage

convexHullArea(f1, f2, group=NULL)
    vowelMeansPolygonArea(f1, f2, vowel, poly.order, group=NULL)

Arguments

See Also

chull, areapl

Examples

Run this code
data(indoVowels)
    hull.area <- with(indo, convexHullArea(f1, f2, group=subj))
    poly.area <- with(indo, vowelMeansPolygonArea(f1, f2, vowel, 
        poly.order=c("i", "e", "a", "o", "u"), group=subj))

Run the code above in your browser using DataLab